<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<!--
The Apache Software License, Version 1.1

Copyright (c) 1999, 2000 The Apache Software Foundation.  All rights
reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. The end-user documentation included with the redistribution, if
   any, must include the following acknowlegement:
      "This product includes software developed by the
       Apache Software Foundation (http://www.apache.org/)."
   Alternately, this acknowlegement may appear in the software itself,
   if and wherever such third-party acknowlegements normally appear.

4. The names "The Jakarta Project", "Ant", and "Apache Software
   Foundation" must not be used to endorse or promote products derived
   from this software without prior written permission. For written
   permission, please contact apache@apache.org.

5. Products derived from this software may not be called "Apache"
   nor may "Apache" appear in their names without prior written
   permission of the Apache Group.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
====================================================================

This software consists of voluntary contributions made by many
individuals on behalf of the Apache Software Foundation.  For more
information on the Apache Software Foundation, please see
<http://www.apache.org/>.
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrn="http://xmlreleasenotes.free.fr" xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect" extension-element-prefixes="redirect" xmlns:xalan="http://xml.apache.org/xalan" exclude-result-prefixes="xrn">
	<!--
	This file belongs to XMLReleaseNotes V0.19.1.
	-->
	<!--
	The aim of this stylesheet is to provide an entry point, so as to extend the framework, by definining new plugins.
	A plugin can be defined at four different levels: the overview, component, the release and the feature.
	When defined at the component level, additional pages will be defined and made available on the 'Component' section.
	The idea is the same for the overview, release and feature levels.
	-->
	<!--
	This stylesheet is the implementation for the plugin part. This URI should be resolved to the actual implementation at runtime.
	-->
	<xsl:import href="XRN2HTMLPlugin"/>
	<xsl:output indent="yes" method="xml" encoding="ISO-8859-1" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/>
	<!--
	This section writes all available plugin HTML pages for a given level.
	The 'level' parameter is expect and should be equal to the level the plugin is supposed to be generated for.
	As for the rest of the present stylesheet, the possible values are 'summary', 'component', 'release' and 'feature'.
	The current node depends on the level:
	- when the level is set to 'summary', it should be a 'Component' XML element,
	- when the level is set to 'component', it should be a 'xrn:ReleaseNotes' XML element,
	- when the level is set to 'release', it should be a 'Release' XML element,
	- when the level is set to 'feature', it should be a 'Feature' XML element.
	This hypothesis holds for the rest of the stylesheet named templates when a 'level' parameter is expected.
	The 'mainURL' parameter is expected and should be equal to the URL of the defaut page generated for the provided level.
	-->
	<xsl:template name="_writePlugin">
		<xsl:param name="level"/>
		<xsl:param name="mainURL"/>
		<xsl:call-template name="_writeOnePlugin">
			<xsl:with-param name="level" select="$level"/>
			<xsl:with-param name="mainURL" select="$mainURL"/>
			<xsl:with-param name="index" select="1"/>
		</xsl:call-template>
	</xsl:template>
	<!--
	This is a helper template that writes a single plugin page.
	The 'index' parameter is expected and should be equal to the plugin cardinal the page should be generated for, at the provided level.
	The 'index' start value is 1.
	-->
	<xsl:template name="_writeOnePlugin">
		<xsl:param name="level"/>
		<xsl:param name="mainURL"/>
		<xsl:param name="index"/>
		<xsl:variable name="pluginCount">
			<xsl:call-template name="printPluginCount">
				<xsl:with-param name="level" select="$level"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:if test="$index &lt;= $pluginCount">
			<xsl:variable name="pluginPagePath">
				<xsl:call-template name="_computePluginPagePath">
					<xsl:with-param name="level" select="$level"/>
					<xsl:with-param name="index" select="$index"/>
				</xsl:call-template>
			</xsl:variable>
			<redirect:write file="{$pluginPagePath}">
				<html>
					<xsl:call-template name="_printHead">
						<xsl:with-param name="title">Plugin of component <xsl:value-of select="../../@ID"/> for version <xsl:value-of select="@version"/>
						</xsl:with-param>
					</xsl:call-template>
					<body>
						<xsl:call-template name="_printPluginNavigation">
							<xsl:with-param name="level" select="$level"/>
							<xsl:with-param name="index" select="$index"/>
							<xsl:with-param name="mainURL" select="$mainURL"/>
						</xsl:call-template>
						<div class="releaseNotes">
							<xsl:choose>
								<xsl:when test="$level = 'release'">
									<xsl:call-template name="_printReleaseVersion"/>
								</xsl:when>
							</xsl:choose>
							<xsl:call-template name="runPlugin">
								<xsl:with-param name="level" select="$level"/>
								<xsl:with-param name="index" select="$index"/>
							</xsl:call-template>
						</div>
					</body>
				</html>
			</redirect:write>
			<xsl:call-template name="_writeOnePlugin">
				<xsl:with-param name="level" select="$level"/>
				<xsl:with-param name="mainURL" select="$mainURL"/>
				<xsl:with-param name="index" select="$index + 1"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!--
	Writes the additional navigation section that enables to access all plugins for the given level.
	The 'index' parameter indicates the plugin ordinal HTML page the navigation is to be generated for.
	-->
	<xsl:template name="_printPluginNavigation">
		<xsl:param name="level"/>
		<xsl:param name="index"/>
		<xsl:param name="mainURL"/>
		<xsl:variable name="pluginCount">
			<xsl:call-template name="printPluginCount">
				<xsl:with-param name="level" select="$level"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:if test="$pluginCount &gt; 0">
			<xsl:variable name="theText">
				<xsl:value-of select="$level"/>
			</xsl:variable>
			<table border="0" width="100%" cellpadding="1" cellspacing="0">
				<tbody>
					<tr>
						<td colspan="2" bgcolor="#EEEEFF" class="NavBarCell1">
							<table border="0" cellpadding="0" cellspacing="3">
								<tbody>
									<tr align="center" valign="top">
										<xsl:choose>
											<xsl:when test="$index = 0">
												<td class="NavBarCell1Rev" bgcolor="#FFFFFF">
													<font class="NavBarFont1Rev">
														<b>
															<xsl:copy-of select="$theText"/>
														</b>
														<xsl:text>&#160;</xsl:text>
													</font>
												</td>
											</xsl:when>
											<xsl:otherwise>
												<td class="NavBarCell1" bgcolor="#EEEEFF">
													<font class="NavBarFont1">
														<a href="{$mainURL}">
															<b>
																<xsl:value-of select="$theText"/>
															</b>
														</a>
														<xsl:text>&#160;</xsl:text>
													</font>
												</td>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:call-template name="_printOnePluginNavigation">
											<xsl:with-param name="level" select="$level"/>
											<xsl:with-param name="index" select="1"/>
											<xsl:with-param name="selected_index" select="$index"/>
										</xsl:call-template>
									</tr>
								</tbody>
							</table>
						</td>
					</tr>
				</tbody>
			</table>
			<br/>
		</xsl:if>
	</xsl:template>
	<!--
	Writes the navigation hyperlink that enables to access the plugin HTML page with a given ordinal.
	The 'index' parameter indicates the plugin ordinal HTML page the navigation is to be generated for.
	The 'selected_index' is expected and indicates the ordinal of the plugin HTML page the hypelink should be generated for .
	-->
	<xsl:template name="_printOnePluginNavigation">
		<xsl:param name="level"/>
		<xsl:param name="index"/>
		<xsl:param name="selected_index"/>
		<xsl:variable name="pluginCount">
			<xsl:call-template name="printPluginCount">
				<xsl:with-param name="level" select="$level"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:if test="$index &lt;= $pluginCount">
			<xsl:variable name="theText">
				<xsl:call-template name="printPluginName">
					<xsl:with-param name="level" select="$level"/>
					<xsl:with-param name="index" select="$index"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="$index = $selected_index">
					<td class="NavBarCell1Rev" bgcolor="#FFFFFF">
						<font class="NavBarFont1Rev">
							<b>
								<xsl:copy-of select="$theText"/>
							</b>
							<xsl:text>&#160;</xsl:text>
						</font>
					</td>
				</xsl:when>
				<xsl:otherwise>
					<td class="NavBarCell1" bgcolor="#EEEEFF">
						<font class="NavBarFont1">
							<a>
								<xsl:attribute name="href"><xsl:call-template name="_computePluginPageHref"><xsl:with-param name="level" select="$level"/><xsl:with-param name="index" select="$index"/></xsl:call-template></xsl:attribute>
								<b>
									<xsl:value-of select="$theText"/>
								</b>
							</a>
							<xsl:text>&#160;</xsl:text>
						</font>
					</td>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:call-template name="_printOnePluginNavigation">
				<xsl:with-param name="level" select="$level"/>
				<xsl:with-param name="index" select="$index + 1"/>
				<xsl:with-param name="selected_index" select="$selected_index"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!--
	Writes the URL of the HTML page that is generated for a given plugin at a given level.
	-->
	<xsl:template name="_computePluginPageHref">
		<xsl:param name="level"/>
		<xsl:param name="index"/>
		<xsl:choose>
			<xsl:when test="$level = 'summary'"/>
			<xsl:when test="$level = 'component'">
				<xsl:value-of select="@ID"/>
				<xsl:text>-</xsl:text>
			</xsl:when>
			<xsl:when test="$level = 'release'">
				<xsl:value-of select="../../@ID"/>
				<xsl:text>-</xsl:text>
				<xsl:value-of select="@version"/>
				<xsl:text>-</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:value-of select="$level"/>
		<xsl:text>-</xsl:text>
		<xsl:call-template name="printPluginSuffixURL">
			<xsl:with-param name="level" select="$level"/>
			<xsl:with-param name="index" select="$index"/>
		</xsl:call-template>
	</xsl:template>
	<!--
	Writes the file path of the HTML page that is generated for a given plugin at a given level.
	-->
	<xsl:template name="_computePluginPagePath">
		<xsl:param name="level"/>
		<xsl:param name="index"/>
		<xsl:value-of select="$destination"/>
		<xsl:text>/</xsl:text>
		<xsl:call-template name="_computePluginPageHref">
			<xsl:with-param name="level" select="$level"/>
			<xsl:with-param name="index" select="$index"/>
		</xsl:call-template>
	</xsl:template>
	<!--
	Writes the suffix URL (including the '.html' extension) of the HTML page that is generated for a given plugin at a given level.
	-->
	<xsl:template name="printPluginSuffixURL">
		<xsl:param name="level"/>
		<xsl:param name="index"/>
		<xsl:variable name="plugins">
			<xsl:call-template name="showPlugins"/>
		</xsl:variable>
		<xsl:value-of select="xalan:nodeset($plugins)/plugins/level[@name = $level]/plugin[position() = $index]/@suffixURL"/>
	</xsl:template>
	<!--
	Prints the number of plugin HTML pages available for a given level.
	-->
	<xsl:template name="printPluginCount">
		<xsl:param name="level"/>
		<xsl:variable name="plugins">
			<xsl:call-template name="showPlugins"/>
		</xsl:variable>
		<xsl:value-of select="count(xalan:nodeset($plugins)/plugins/level[@name = $level]/plugin)"/>
	</xsl:template>
	<!--
	Prints the name of a given plugin for a given level.
	-->
	<xsl:template name="printPluginName">
		<xsl:param name="level"/>
		<xsl:param name="index"/>
		<xsl:variable name="plugins">
			<xsl:call-template name="showPlugins"/>
		</xsl:variable>
		<xsl:value-of select="xalan:nodeset($plugins)/plugins/level[@name = $level]/plugin[position() = $index]/@name"/>
	</xsl:template>
</xsl:stylesheet>
