<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<!--
The Apache Software License, Version 1.1

Copyright (c) 1999, 2000 The Apache Software Foundation.  All rights
reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. The end-user documentation included with the redistribution, if
   any, must include the following acknowlegement:
      "This product includes software developed by the
       Apache Software Foundation (http://www.apache.org/)."
   Alternately, this acknowlegement may appear in the software itself,
   if and wherever such third-party acknowlegements normally appear.

4. The names "The Jakarta Project", "Ant", and "Apache Software
   Foundation" must not be used to endorse or promote products derived
   from this software without prior written permission. For written
   permission, please contact apache@apache.org.

5. Products derived from this software may not be called "Apache"
   nor may "Apache" appear in their names without prior written
   permission of the Apache Group.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
====================================================================

This software consists of voluntary contributions made by many
individuals on behalf of the Apache Software Foundation.  For more
information on the Apache Software Foundation, please see
<http://www.apache.org/>.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrn="http://xmlreleasenotes.free.fr" version="1.0">
	<!--
	This file belongs to XMLReleaseNotes V@XRN_VERSION@.
	-->
	<!--
	The aim of this model XSLT is to enable the use of an actors XML external file that will contain information about the persons involved in the process.
	-->
	<xsl:import href="XRNModelCommon.xsl"/>
	<xsl:import href="XMLReleaseNotesCommon.xsl"/>
	<xsl:output method="xml" indent="yes"/>
	<!--
	This indicates the path of the XML file that describes all actors, and that complies to the XRN 'XRNActors.xsd' schema.
	Be careful when specifying the value: relative paths works often better than absolute paths.
	May be not provided, and in that case, no additional actor file is being added.
	-->
	<xsl:param name="actorsFile" select="false()"/>
	<!--
	This indicates whether any existing actors file already present should be removed or not.
	-->
	<xsl:param name="removeExistingActors" select="false()"/>
	<!--
	This indicates whether the actors identifiers should be replaced by their display name or not.
	-->
	<xsl:param name="expandActorName" select="false()"/>
	<!--
	This indicates whether the actors identifiers should all be equalized to the same case or not.
	-->
	<xsl:param name="equalizeCase" select="false()"/>
	<!--
	This indicates whether the actors identifiers should be checked against those present in the 'actorsFile' file (which should be provided in that case).
	This enables to tests whether only known actors will output in the final release notes. Messages are output for each mismatching.
	-->
	<xsl:param name="checkActors" select="false()"/>
	<xsl:template match="xrn:ReleaseNotes">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:if test="$actorsFile">
				<Actors>
					<xsl:attribute name="href"><xsl:value-of select="$actorsFile"/></xsl:attribute>
				</Actors>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="$removeExistingActors">
					<xsl:apply-templates select="*[not(name() = 'Actors')]"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="Releases/Release">
		<xsl:copy>
			<xsl:copy-of select="@*[not(name() = 'builderID')]"/>
			<xsl:attribute name="builderID"><xsl:call-template name="_getActorID"><xsl:with-param name="actorID" select="@builderID"/></xsl:call-template></xsl:attribute>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="Features/Feature">
		<xsl:copy>
			<xsl:copy-of select="@*[not(name() = 'contributorID' or name() = 'askingPersonID')]"/>
			<xsl:attribute name="contributorID"><xsl:call-template name="_getActorID"><xsl:with-param name="actorID" select="@contributorID"/></xsl:call-template></xsl:attribute>
			<xsl:attribute name="askingPersonID"><xsl:call-template name="_getActorID"><xsl:with-param name="actorID" select="@askingPersonID"/></xsl:call-template></xsl:attribute>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="Actor">
		<xsl:copy>
			<xsl:copy-of select="@*[not(name() = 'ID')]"/>
			<xsl:attribute name="ID"><xsl:call-template name="_getActorID"><xsl:with-param name="actorID" select="@ID"/></xsl:call-template></xsl:attribute>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:template>
	<!--
	Retrieves the actor display name from the provided 'actorsFile' parameter.
	The 'actorID' parameter is expected and should be equal to the identifier for which its display name is to be output.
	-->
	<xsl:template name="_getActorID">
		<xsl:param name="actorID"/>
		<!-- We check that the actor is present in the XML file. -->
		<xsl:if test="$checkActors and $actorsFile and not($actorID = '') and $actorID">
			<xsl:if test="not(document($actorsFile)/*/Person[@ID = $actorID])">
				<xsl:message>Cannot find the actor with name '<xsl:value-of select="$actorID"/>'</xsl:message>
			</xsl:if>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="$expandActorName">
				<xsl:call-template name="_getActorIDFromFile">
					<xsl:with-param name="actorID" select="$actorID"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$equalizeCase">
				<xsl:call-template name="_equalizeActorIDCase">
					<xsl:with-param name="actorID" select="$actorID"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$actorID"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Retrieves the actor display name from the provided 'actorsFile' stylesheet top parameter.
	The 'actorID' parameter is expected and should be equal to the identifier for which its display name is to be output.
	-->
	<xsl:template name="_equalizeActorIDCase">
		<xsl:param name="actorID"/>
		<xsl:value-of select="translate($actorID, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ', 'abcdefghijklmnopqrstuvwxyz')"/>
	</xsl:template>
	<!--
	Retrieves the actor display name from the provided 'actorsFile' stylesheet top parameter.
	The 'actorID' parameter is expected and should be equal to the identifier for which its display name is to be output.
	-->
	<xsl:template name="_getActorIDFromFile">
		<xsl:param name="actorID"/>
		<xsl:choose>
			<xsl:when test="$actorsFile">
				<xsl:choose>
					<xsl:when test="document($actorsFile)/*/Person[@ID = $actorID]">
						<xsl:value-of select="document($actorsFile)/*/Person[@ID = $actorID]/@displayName"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$actorID"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$actorID"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
